Crate rbx_ds_cloud
source · [−]Expand description
rbx-ds-cloud - CLI and Library for Roblox’s Datastore OpenCloud API
rbx-ds-cloud is a CLI and Library for the Roblox Datastore Open Cloud API.
To learn how to use the CLI visit the website documentation
Add to your project
Add rbx-ds-cloud as a dependency
$ cargo add rbx_ds_cloudTutorial
Check out the examples directory in the repository of the project
Modules
Access to the Roblox Datastore Open Cloud API