Module datastore_api

Module datastore_api 

All the functions interacting with the Roblox Datastore Open Cloud API

Functions

delete_entry
Marks the entry as deleted by creating a tombstone version. Entries are deleted permanently after 30 days.
get_entry
Returns the value associated with an entry.
get_entry_version
Returns the metadata of a specific version of an entry.
increment_entry
Increments the value for an entry by a given amount, or create a new entry with that amount.
list_data_stores
List all Datastores in the specified “universe” or game
list_entries
Returns a list of entry keys within a data store.
list_entries_version
Returns the versions and metadata of an Entry of a datastore
set_entry
Sets the value, metadata and user IDs associated with an entry.