Module endpoint_structs

Module endpoint_structs 

Structs used as Arguments for the Roblox API

Structs

DeleteEntry
Marks the entry as deleted by creating a tombstone version. Entries are deleted permanently after 30 days.
GetEntry
Returns the value associated with an entry.
GetEntryVersion
Returns the metadata of a specific version of an entry.
IncrementEntry
Increments the value for an entry by a given amount, or create a new entry with that amount.
ListDataStores
List all Datastores in the specified “universe” or game
ListEntries
Returns a list of entry keys within a data store.
ListEntryVersions
Returns the versions and metadata of an Entry of a datastore
SetEntry
Sets the value, metadata and user IDs associated with an entry.

Enums

SortOrder
An Enum for the ListEntryVersions API