Module response_structs

Module response_structs 

Some of the responses from the Roblox API are deserialized into these structs, I suppose this section would not need any documentation because, honestly, I do not know what to write

Structs

EntryVersion
ListDataStoreIndex
ListDataStoresResponse
ListEntriesIndex
ListEntriesResponse
ListEntryVersionResponse