Access to the Roblox Datastore Open Cloud API
Modules
- datastore_
api - All the functions interacting with the Roblox Datastore Open Cloud API
- endpoint_
structs - Structs used as Arguments for the Roblox API
- error_
types - Error handling and stuff
- response_
structs - Some of the responses from the Roblox API are deserialized into these structs, I suppose this section would not need any documentation because, honestly, I do not know what to write