Access to the Roblox Datastore Open Cloud API

Modules

All the functions interacting with the Roblox Datastore Open Cloud API

Structs used as Arguments for the Roblox API

Error handling and stuff

Some of the responses from the Roblox API are deserialized into these structs, I suppose this section would not any documentation because, honestly, I do not know what to write