All the functions interacting with the Roblox Datastore Open Cloud API
Functions
- delete_
entry - Marks the entry as deleted by creating a tombstone version. Entries are deleted permanently after 30 days.
- get_
entry - Returns the value associated with an entry.
- get_
entry_ version - Returns the metadata of a specific version of an entry.
- increment_
entry - Increments the value for an entry by a given amount, or create a new entry with that amount.
- list_
data_ stores - List all Datastores in the specified “universe” or game
- list_
entries - Returns a list of entry keys within a data store.
- list_
entries_ version - Returns the versions and metadata of an Entry of a datastore
- set_
entry - Sets the value, metadata and user IDs associated with an entry.