Module rbx_ds_cloud::api::datastore_api
source · [−]Expand description
All the functions interacting with the Roblox Datastore Open Cloud API
Functions
Marks the entry as deleted by creating a tombstone version. Entries are deleted permanently after 30 days.
Returns the value associated with an entry.
Returns the metadata of a specific version of an entry.
Increments the value for an entry by a given amount, or create a new entry with that amount.
List all Datastores in the specified “universe” or game
Returns a list of entry keys within a data store.
Returns the versions and metadata of an Entry of a datastore
Sets the value, metadata and user IDs associated with an entry.