Function rbx_ds_cloud::api::datastore_api::increment_entry
source · [−]pub async fn increment_entry(
increment_struct: &IncrementEntry
) -> Result<Response, Error>Expand description
Increments the value for an entry by a given amount, or create a new entry with that amount.