Structs used as Arguments for the Roblox API
Structs
- Delete
Entry - Marks the entry as deleted by creating a tombstone version. Entries are deleted permanently after 30 days.
- GetEntry
- Returns the value associated with an entry.
- GetEntry
Version - Returns the metadata of a specific version of an entry.
- Increment
Entry - Increments the value for an entry by a given amount, or create a new entry with that amount.
- List
Data Stores - List all Datastores in the specified “universe” or game
- List
Entries - Returns a list of entry keys within a data store.
- List
Entry Versions - Returns the versions and metadata of an Entry of a datastore
- SetEntry
- Sets the value, metadata and user IDs associated with an entry.
Enums
- Sort
Order - An Enum for the ListEntryVersions API