pub struct IncrementEntry {
    pub universe_id: u64,
    pub api_key: String,
    pub datastore_name: String,
    pub scope: Option<String>,
    pub key: String,
    pub increment_by: f64,
    pub user_ids: Option<Vec<u64>>,
    pub attributes: Option<String>,
}
Increments the value for an entry by a given amount, or create a new entry with that amount.

Fields

universe_id: u64

The value of DataModel.GameId, which is visible in the URL on the universe’s Configure page.

api_key: String

API key of Roblox Open Cloud

datastore_name: String

Name of the data store

scope: Option<String>

(Optional) If “None”, defaults to global, similar to Lua API

key: String

The key which identifies the entry

increment_by: f64

The amount by which the entry should be incremented

user_ids: Option<Vec<u64>>

(Optional) Comma-separated list of Roblox user IDs

attributes: Option<String>

(Optional) JSON-stringified attributes data