Struct rbx_ds_cloud::api::endpoint_structs::IncrementEntry
source · [−]pub struct IncrementEntry {
pub universe_id: u64,
pub api_key: String,
pub datastore_name: String,
pub scope: Option<String>,
pub key: String,
pub increment_by: f64,
pub user_ids: Option<Vec<u64>>,
pub attributes: Option<String>,
}Expand description
Increments the value for an entry by a given amount, or create a new entry with that amount.
Fields
universe_id: u64The value of DataModel.GameId, which is visible in the URL on the universe’s Configure page.
api_key: StringAPI key of Roblox Open Cloud
datastore_name: StringName of the data store
scope: Option<String>(Optional) If “None”, defaults to global, similar to Lua API
key: StringThe key which identifies the entry
increment_by: f64The amount by which the entry should be incremented
user_ids: Option<Vec<u64>>(Optional) Comma-separated list of Roblox user IDs
attributes: Option<String>(Optional) JSON-stringified attributes data