Module rbx_ds_cloud::api::response_structs
source · [−]Expand description
Some of the responses from the Roblox API are deserialized into these structs, I suppose this section would not any documentation because, honestly, I do not know what to write